Distribution package
====================

This package consists of several distribution modules. 
It also includes :mod:`metasyn.distribution.base` module, which forms the basis of all distributions.

Base module
^^^^^^^^^^^

.. automodule:: metasyn.distribution.base
   :members:
   :undoc-members:
   :inherited-members:
   :private-members:
   :show-inheritance:

Categorical module
^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.distribution.categorical
   :members:
   :undoc-members:
   :inherited-members:
   :private-members:
   :show-inheritance:

Constant module
^^^^^^^^^^^^^^^

.. automodule:: metasyn.distribution.constant
   :members:
   :undoc-members:
   :inherited-members:
   :private-members:
   :show-inheritance:

Continuous module
^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.distribution.continuous
   :members:
   :undoc-members:
   :inherited-members:
   :private-members:
   :show-inheritance:

Datetime module
^^^^^^^^^^^^^^^

.. automodule:: metasyn.distribution.datetime
   :members:
   :undoc-members:
   :inherited-members:
   :private-members:
   :show-inheritance:

Discrete module
^^^^^^^^^^^^^^^

.. automodule:: metasyn.distribution.discrete
   :members:
   :undoc-members:
   :inherited-members:
   :private-members:
   :show-inheritance:

Faker module
^^^^^^^^^^^^

.. automodule:: metasyn.distribution.faker
   :members:
   :undoc-members:
   :inherited-members:
   :private-members:
   :show-inheritance:

NA module
^^^^^^^^^

.. automodule:: metasyn.distribution.na
   :members:
   :undoc-members:
   :inherited-members:
   :private-members:
   :show-inheritance:

Regex module
^^^^^^^^^^^^

.. automodule:: metasyn.distribution.regex
   :members:
   :undoc-members:
   :inherited-members:
   :private-members:
   :show-inheritance:


